/*
 * Copyright 2013 Canonical Ltd.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * telephony-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1
import Friends 0.1

Item {
    property string stream: ""
    property int unseen: 0
    property string search

    Behavior on x {
        SequentialAnimation{
            PropertyAction { property: "x"; value: main.width }
            PropertyAnimation { duration: 400 }
        }
    }

    function top () {
        listView.positionViewAtEnd();
    }

    onUnseenChanged: {
        updatesText.text = unseen == 1 ? (unseen + i18n.tr(" new update")) : (unseen + i18n.tr(" new updates"));
    }

    Component {
        id: statusDelegate
        StatusUpdateTile {
            id: content
            width: ListView.view.width
            height: childrenRect.height
            ListView.onAdd: SequentialAnimation {
                ScriptAction { script: {unseen++; console.log(column_0[0][0] + " " + column_0[0][1] + " " + column_0[0][2]) }}
            }
            ThinDivider {}
        }
    }
    
    StreamModel {
        id: streamModel
    }

    onStreamChanged: {
        console.log("stream changed to " + stream);
        streamModel.stream = stream;
    }

    onSearchChanged: {
        console.log ("onSearchChanged");
    }

    ListView {
        id: listView
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }
        model: streamModel
        //snapMode: ListView.SnapToItem
        verticalLayoutDirection: ListView.BottomToTop
        cacheBuffer: parent.height

        delegate: statusDelegate
        focus: true

        populate: Transition {
            ScriptAction { script: waitTimer.start() }
        }

        Item {
            id: updatesBanner
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
                topMargin: units.gu(1)
            }
            width: parent.width
            visible: unseen > 0
            Rectangle {
                anchors.centerIn: parent
                color: "lightgray"
                height: updatesText.height + units.gu(2)
                width: parent.width
                Text {
                    id: updatesText
                    anchors {
                        centerIn: parent
                        margins: units.gu(2)
                    }
                    text: ""
                    height: 10
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        unseen = 0;
                        updatesText.text = "";
                        updatesBanner.visible = false;
                        listView.positionViewAtEnd();
                    }
                }
            }
        }
    }

    Timer {
        id: waitTimer
        interval: 500
        repeat: false
        triggeredOnStart: false
        running: false
        onTriggered: { 
            listView.positionViewAtEnd();
        }
    }

    Scrollbar {
        flickableItem: listView
        align: Qt.AlignTrailing
    }


}
